@@ -258,6 +258,8 @@ GsmApplication::load_settings ()
 
   this->settings = Gio::Settings::create (GSM_GSETTINGS_SCHEMA);
 
+  config.current_tab = this->settings->get_string (GSM_SETTING_CURRENT_TAB);
+
   config.solaris_mode = this->settings->get_boolean (GSM_SETTING_SOLARIS_MODE);
   this->settings->signal_changed (GSM_SETTING_SOLARIS_MODE).connect ([this](const Glib::ustring&key) {
     cb_solaris_mode_changed (*this->settings.operator-> (), key, this);
@@ -458,15 +460,17 @@ GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>
       exit (EXIT_SUCCESS);
     }
 
+  const char* tab = NULL;
   if (option_group.show_processes_tab)
-    this->settings->set_string (GSM_SETTING_CURRENT_TAB, "processes");
+    tab = "processes";
   else if (option_group.show_resources_tab)
-    this->settings->set_string (GSM_SETTING_CURRENT_TAB, "resources");
+    tab = "resources";
   else if (option_group.show_file_systems_tab)
-    this->settings->set_string (GSM_SETTING_CURRENT_TAB, "disks");
-  else if (option_group.print_version)
+    tab = "disks";
+  if (tab)
+    gtk_stack_set_visible_child_name (this->stack, tab);
 
-    on_activate ();
+  on_activate ();
 
   return 0;
 }
@@ -562,7 +566,7 @@ GsmApplication::on_startup ()
   add_accelerator ("<Primary>q", "app.quit", NULL);
   add_accelerator ("<Primary>s", "win.send-signal-stop", g_variant_new_int32 (SIGSTOP));
   add_accelerator ("<Primary>c", "win.send-signal-cont", g_variant_new_int32 (SIGCONT));
-  add_accelerator ("<Primary>e", "win.send-signal-end", g_variant_new_int32 (SIGTERM));
+  add_accelerator ("<Primary>t", "win.send-signal-term", g_variant_new_int32 (SIGTERM));
   add_accelerator ("<Primary>k", "win.send-signal-kill", g_variant_new_int32 (SIGKILL));
   add_accelerator ("<Alt>s", "win.set-affinity", NULL);
   add_accelerator ("<Primary>m", "win.memory-maps", NULL);
@@ -571,6 +575,7 @@ GsmApplication::on_startup ()
   add_accelerator ("<Primary>f", "win.search", g_variant_new_boolean (TRUE));
   add_accelerator ("F1", "app.help", NULL);
   add_accelerator ("<Primary>question", "win.show-help-overlay", NULL);
+  add_accelerator ("<Primary>comma", "app.preferences", NULL);
 
   Gtk::Window::set_default_icon_name ("org.gnome.SystemMonitor");
 
